import { Collection, Interaction } from 'discord.js';
import BaseInteractionHandler from './BaseInteractionHandler';
/**
 * @type
 */
export declare type InteractionCtor<I extends Interaction> = {
    new (...args: any[]): I;
};
/**
 * The base interaction manager
 * @class
 */
export default abstract class BaseInteractionManager<I extends Interaction, H extends BaseInteractionHandler, ID_TYPE = string> {
    _interactionCtor: InteractionCtor<I>;
    /**
     * A Collection of interaction handlers
     * @protected
     */
    protected interactionHandlers: Collection<ID_TYPE, H>;
    /**
     * @constructor
     * @param {InteractionCtor} _interactionCtor
     * @public
     */
    constructor(_interactionCtor: InteractionCtor<I>);
    /**
     * Registers a new Interaction Handler inside of a Collection
     * @param {ID_TYPE} Id The Id to set as the key
     * @param {H} handler The handler to set as the value
     * @method
     * @public
     */
    registerInteractionHandler(Id: ID_TYPE, handler: H): void;
    /**
     * Removes a Handler from the Interactions Handler Collection
     * @param {ID_TYPE} Id The Id to delete
     * @method
     * @public
     * @returns
     */
    removeInteractionHandler(Id: ID_TYPE): boolean;
    /**
     * Fetches an Interaction handler
     * @param {I} interaction The interaction to get
     * @method
     * @protected
     * @returns
     */
    protected getInteractionHandler(interaction: I): H | undefined;
    /**
     * Get an interaction via Id
     * @param {T} interaction The interaction to get.
     * @method
     * @abstract
     * @protected
     */
    protected abstract getInteractionId(interaction: I): ID_TYPE;
    /**
     * Calls an interaction function
     * @param {I} interaction The interaction to call
     * @method
     * @abstract
     * @protected
     */
    protected abstract callInteraction(interaction: I): void;
    /**
     * Call an interaction based on an event
     * @param {I} interaction The interaction to listen for
     * @method
     * @public
     */
    onInteraction(interaction: I): void;
}
